libgraphviz: Graph visualization software (callable library)
============================================================

Description
-----------

Graphviz is open source graph visualization software. It has several main graph layout programs.
They take descriptions of graphs in a simple text language, and make diagrams in several useful formats.

This script package represents the callable library.

License
-------

Eclipse Public License 1.0

Upstream Contact
----------------

https://graphviz.org/about/
